==> cosec-core-1.16.7-sources.jar: me/ahoo/cosec/policy/condition/part/InConditionMatcher.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.cosec.policy.condition.part

import me.ahoo.cosec.api.configuration.Configuration
import me.ahoo.cosec.api.policy.ConditionMatcher
import me.ahoo.cosec.policy.condition.ConditionMatcherFactory

class InConditionMatcher(configuration: Configuration) :
    PartConditionMatcher(InConditionMatcherFactory.TYPE, configuration) {
    private val value: Set<String> = configuration.getRequired(STARTS_WITH_CONDITION_MATCHER_VALUE_KEY)
        .asStringList().toSet()

    override fun matchPart(partValue: String): Boolean {
        return value.contains(partValue)
    }
}

class InConditionMatcherFactory : ConditionMatcherFactory {
    companion object {
        const val TYPE = "in"
    }

    override val type: String
        get() = TYPE

    override fun create(configuration: Configuration): ConditionMatcher {
        return InConditionMatcher(configuration)
    }
}

==> cosec-core-2.3.4-sources.jar: me/ahoo/cosec/policy/condition/part/InConditionMatcher.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.cosec.policy.condition.part

import me.ahoo.cosec.api.configuration.Configuration
import me.ahoo.cosec.api.context.SecurityContext
import me.ahoo.cosec.api.policy.ConditionMatcher
import me.ahoo.cosec.policy.condition.ConditionMatcherFactory

class InConditionMatcher(configuration: Configuration) :
    PartConditionMatcher(InConditionMatcherFactory.TYPE, configuration) {
    private val value: Set<String> = configuration.getRequired(CONDITION_MATCHER_VALUE_KEY)
        .asStringList().toSet()

    override fun matchPart(partValue: String, securityContext: SecurityContext): Boolean {
        return value.contains(partValue)
    }
}

class InConditionMatcherFactory : ConditionMatcherFactory {
    companion object {
        const val TYPE = "in"
    }

    override val type: String
        get() = TYPE

    override fun create(configuration: Configuration): ConditionMatcher {
        return InConditionMatcher(configuration)
    }
}
